pub struct Sender {
pub tx: UnboundedSender<TxnMsgWithPermits>,
permits: Arc<Permits>,
max_chunk_permits: usize,
}Expand description
The sender of the transaction channel with permit-based back-pressure.
Fields
tx: UnboundedSender<TxnMsgWithPermits>permits: Arc<Permits>max_chunk_permits: usizeThe maximum permits required by a chunk. If there’re too many rows in a chunk, we only acquire these permits.
Implementations
Sourceimpl Sender
impl Sender
Sourcepub async fn send(
&self,
txn_msg: TxnMsg,
notificator: Sender<usize>,
) -> Result<(), SendError<TxnMsg>>
pub async fn send( &self, txn_msg: TxnMsg, notificator: Sender<usize>, ) -> Result<(), SendError<TxnMsg>>
Send a message, waiting until there are enough permits. Used to send transaction data messages.
Returns error if the receive half of the channel is closed, including the message passed.
Sourcepub fn send_immediate(
&self,
txn_msg: TxnMsg,
notificator: Sender<usize>,
) -> Result<(), SendError<TxnMsg>>
pub fn send_immediate( &self, txn_msg: TxnMsg, notificator: Sender<usize>, ) -> Result<(), SendError<TxnMsg>>
Send a message without permit acquiring. Used to send transaction control messages.
Returns error if the receive half of the channel is closed, including the message passed.
pub fn is_closed(&self) -> bool